/*
** Module   : SaxReader
** Abstract : SAX reader specific interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130208 Created initial version.
** 002 CA  20130221 Added ADM-DATA and UNIQUE-ID support. 
** 003 EVL 20130320 Adding SAX reader related literal constants.
** 004 EVK 20130903 Moved SuppressNamespaceProcessing methods to the new interface XmlSchema.
** 005 CA  20130927 Added LegacyResource annotation, to determine resource type.
** 006 EVL 20130911 Adding legacy attributes and methods annotation.
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Interface describing SAX-Reader specific features of the SAX objects.
 */
@LegacyResource(resource = LegacyResource.SAX_READER)
public interface SaxReader
extends SaxEntity,
        UniqueID,
        ADMData,
        XmlSchema
{
   /**
    * The SAX-UNINITIALIZE constant returned by the PARSE-STATUS attribute, which in 4GL is the
    * integer value 1.
    */
   public final static int SAX_UNINITIALIZED = 1;

   /**
    * The SAX-RUNNING constant returned by the PARSE-STATUS attribute, which in 4GL is the
    * integer value 2.
    */
   public final static int SAX_RUNNING = 2;

   /**
    * The SAX-COMPLETE constant returned by the PARSE-STATUS attribute, which in 4GL is the
    * integer value 3.
    */
   public final static int SAX_COMPLETE = 3;

   /**
    * The SAX-PARSER-ERROR constant returned by the PARSE-STATUS attribute, which in 4GL is the
    * integer value 4.
    */
   public final static int SAX_PARSER_ERROR = 4;
   
   // Attributes
   /**
    * Gets the value of the handler attribute for the given SAX Reader object.
    * 
    * @return   The handle variable representing the handler attribute.
    */
   @LegacyAttribute(name = "HANDLER")
   public handle getHandler();

   /**
    * Sets the value of the handler attribute for the given SAX Reader object.
    * 
    * @param    hCallback
    *           The handle of the new callback handler to be set for the handler attribute.
    */
   @LegacyAttribute(name = "HANDLER", setter = true)
   public void setHandler(handle hCallback);
   
   /**
    * Gets the value of the current 1-based column in XML source.
    * 
    * @return   The integer value of the current column.
    */
   @LegacyAttribute(name = "LOCATOR-COLUMN-NUMBER")
   public integer getLocatorColumnNumber();

   /**
    * Gets the value of the current 1-based line number in XML source.
    * 
    * @return   The integer value of the current line.
    */
   @LegacyAttribute(name = "LOCATOR-LINE-NUMBER")
   public integer getLocatorLineNumber();
   
   /**
    * Gets the current value of the parse status. The default value is {@link #SAX_UNINITIALIZED}.
    * The other returned values are {@link #SAX_COMPLETE}, {@link #SAX_PARSER_ERROR} or 
    * {@link #SAX_RUNNING}.
    * 
    * @return   The integer value representing the current status of the parse.
    */
   @LegacyAttribute(name = "PARSE-STATUS")
   public integer getParseStatus();
   
   /**
    * Gets the current value of the public identifier of the current XML source.
    * 
    * @return   The character value representing the current locator-public-id attribute.
    */
   @LegacyAttribute(name = "LOCATOR-PUBLIC-ID")
   public character getLocatorPublicId();

   /**
    * Gets the current value of the system identifier of the current XML source.
    * 
    * @return   The character value representing the current locator-system-id attribute.
    */
   @LegacyAttribute(name = "LOCATOR-SYSTEM-ID")
   public character getLocatorSystemId();

   /**
    * Gets the current value of the namespace location pair mapping.
    * 
    * @return   The character value representing the current schema-location attribute.
    */
   @LegacyAttribute(name = "SCHEMA-LOCATION")
   public character getSchemaLocation();
   
   /**
    * Sets the current value of the namespace location pair mapping.
    * 
    * @param    location
    *           The new value the current schema-location attribute.
    */
   @LegacyAttribute(name = "SCHEMA-LOCATION", setter = true)
   public void setSchemaLocation(character location);
   
   /**
    * Sets the current value of the namespace location pair mapping.
    * 
    * @param    location
    *           The new value the current schema-location attribute.
    */
   @LegacyAttribute(name = "SCHEMA-LOCATION", setter = true)
   public void setSchemaLocation(String location);
   
   /**
    * Gets the delimiter separated list of directory paths used to locate XML DTD associated with
    * a particular XML document.
    * 
    * @return   The character value representing the current schema-path attribute.
    */
   @LegacyAttribute(name = "SCHEMA-PATH")
   public character getSchemaPath();
   
   /**
    * Sets the delimiter separated list of directory paths used to locate XML DTD associated with
    * a particular XML document.
    * 
    * @param    path
    *           The new value the current schema-path attribute.
    */
   @LegacyAttribute(name = "SCHEMA-PATH", setter = true)
   public void setSchemaPath(character path);
   
   /**
    * Sets the delimiter separated list of directory paths used to locate XML DTD associated with
    * a particular XML document.
    * 
    * @param    path
    *           The new value the current schema-path attribute.
    */
   @LegacyAttribute(name = "SCHEMA-PATH", setter = true)
   public void setSchemaPath(String path);
   
   /**
    * Indicates if the parser validates the XML document against DTD or not.
    *
    * @return   The logical value representing the current validation-enabled attribute.
    */
   @LegacyAttribute(name = "VALIDATION-ENABLED")
   public logical getValidationEnabled();
   
   /**
    * Redefines whether the parser will validate the XML document against DTD or not.
    * 
    * @param    enable
    *           The new value the current validation-enabled attribute.
    */
   @LegacyAttribute(name = "VALIDATION-ENABLED", setter = true)
   public void setValidationEnabled(logical enable);
   
   /**
    * Redefines whether the parser will validate the XML document against DTD or not.
    * 
    * @param    enable
    *           The new value the current validation-enabled attribute.
    */
   @LegacyAttribute(name = "VALIDATION-ENABLED", setter = true)
   public void setValidationEnabled(boolean enable);
   
   // Methods
   /**
    * Executing single call parse of an XML document associated with a SAX-Reader object.
    */
   @LegacyMethod(name = "SAX-PARSE")
   public void saxParse();

   /**
    * Initializes and begins progressice-scan parse of an XML document associated with a
    * SAX-Reader object.
    */
   @LegacyMethod(name = "SAX-PARSE-FIRST")
   public void saxParseFirst();

   /**
    * Continues progressice-scan parse of an XML document associated with a SAX-Reader object.
    */
   @LegacyMethod(name = "SAX-PARSE-NEXT")
   public void saxParseNext();

   /**
    * Specifies the input source of the XML document to be parsed by a SAX-Reader object.
    * 
    * @param    mode
    *           The type of the object to process. Can be 'FILE', 'HANDLE', 'MEMPTR' or
    *           'LONGCHAR'.
    * @param    source
    *           The appropriate object to process.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @LegacyMethod(name = "SET-INPUT-SOURCE")
   public logical setInputSource(String mode, Object source);

   /**
    * Specifies the input source of the XML document to be parsed by a SAX-Reader object.
    * 
    * @param    mode
    *           The type of the object to process. Can be 'FILE', 'HANDLE', 'MEMPTR' or
    *           'LONGCHAR'.
    * @param    source
    *           The appropriate object to process.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @LegacyMethod(name = "SET-INPUT-SOURCE")
   public logical setInputSource(character mode, Object source);
   
   /**
    * Causes parser to stop parsing the XML document.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @LegacyMethod(name = "STOP-PARSING")
   public logical stopParsing();
}
